-----------------------------------------------------------------------------------------------
-- Client Lua Script for TestCooldown
-- Copyright (c) Foxykeep. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"


-----------------------------------------------------------------------------------------------
-- TestCooldown Module Definition
-----------------------------------------------------------------------------------------------
local TestCooldown = {}


-----------------------------------------------------------------------------------------------
-- TestCooldown Initialization
-----------------------------------------------------------------------------------------------

function TestCooldown:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self

    return o
end

function TestCooldown:Init()
    Apollo.RegisterAddon(self)
end


-----------------------------------------------------------------------------------------------
-- TestCooldown OnLoad
-----------------------------------------------------------------------------------------------

function TestCooldown:OnLoad()

	Apollo.RegisterSlashCommand("tcd", "TestCooldown", self)
end


-----------------------------------------------------------------------------------------------
-- Cooldown detection
-----------------------------------------------------------------------------------------------

-- Check if a spell is currently on cooldown
-- @return [time remaining, duration, remaining charges]
function TestCooldown:GetSpellCooldown(s)
	if not s then 
		Print("GetSpellCooldown called with a nil spell")
		return 0, 0, 0 
	end
	local c = s:GetAbilityCharges() -- check for spells with charges
	if c and c.nChargesMax > 0 then
		if c.fRechargePercentRemaining and c.fRechargePercentRemaining > 0 then
			return c.fRechargePercentRemaining * c.fRechargeTime, c.fRechargeTime, tostring(c.nChargesRemaining)
		end
	else
		local t = s:GetCooldownRemaining() -- check for spells with simple cooldowns
		if t and t > 0 then return t, s:GetCooldownTime(), 0 end -- time remaining is greater than 0 when on cooldown
	end
	return 0, 0, 0 -- not on cooldown
end

function TestCooldown:TestCooldown(cmd, spellName)
	Print("[TestCooldown] Checking cooldown for spell: " .. spellName .. " ...")

	local abilities = AbilityBook.GetAbilitiesList()
	if not abilities then
		return
	end

	 for _, v in pairs(abilities) do
	 	if v.strName == spellName then
			if v.bIsActive and v.nCurrentTier and v.tTiers then
				local tier = v.tTiers[v.nCurrentTier]
				if tier then

					local timeLeft, duration, charges = self:GetSpellCooldown(tier.splObject)
					Print("[TestCooldown] Spell " .. spellName .. " | cooldown: " .. timeLeft)
					return
				end
			end
		end
	end

	 Print("[TestCooldown] Spell not found :(")
end
 
-----------------------------------------------------------------------------------------------
-- TestCooldown Instance
-----------------------------------------------------------------------------------------------
local TestCooldownInst = TestCooldown:new()
TestCooldownInst:Init()






